@@ -17,9 +17,7 @@ package com.clustercontrol.agent;
 
 import java.util.ArrayList;
 import java.util.Collection;
-import java.util.ConcurrentModificationException;
 import java.util.Date;
-import java.util.Enumeration;
 import java.util.Hashtable;
 import java.util.Iterator;
 import java.util.Properties;
@@ -59,7 +57,7 @@ import com.clustercontrol.jobmanagement.message.RunResultInfo;
  * 
  * Topicでマネージャからのジョブ実行指示を受け取ります。
  * 
- * @version $Revision: 3983 $
+ * @version $Revision: 3506 $
  * @since 1.0.0
  * 
  */
@@ -521,25 +519,6 @@ public class ReceiveTopic implements MessageListener, ExceptionListener {
 	}
 	
 	
-	/**
-	 * 実行履歴をログに出力
-	 * @return
-	 */
-	protected void logHistory() {
-		
-		synchronized (m_runHistory) {
-			
-			try {
-				for(String key : m_runHistory.keySet()) {
-					log.info("A running job is out of control due to stopped agent : " + key);			
-				}							
-			} catch (ConcurrentModificationException e) {
-				log.warn("Log output process is stopped due to job execution history updated at the same time.");	
-			}
-		}
-	}
-	
-	
 	/**
 	 * EJB再接続タイマータスク
 	 * 通信エラーとなった場合に定周期で呼ばれ再接続を行う 
