@@ -15,6 +15,7 @@ PURPOSE.  See the GNU General Public License for more details.
 
 package com.clustercontrol.etc.action;
 
+import com.clustercontrol.action.FacilityTree;
 import com.clustercontrol.composite.FacilityTreeComposite;
 
 /**
@@ -43,6 +44,10 @@ public class UpdateFacilityTreeTask implements Runnable {
      * 
      */
     public void run() {
+    	// ローカルキャッシュを消去
+    	FacilityTree.clearCache();
+    	
+    	// マネージャから情報取得
         this.target.update();
     }
 }
\ No newline at end of file
