@@ -317,7 +317,7 @@ public class JobNoticeInfoDAOImpl implements JobNoticeInfoDAO {
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();	
 			//SQL文の定義
-			String sql = "SELECT * FROM cc_job_notice_info";
+			String sql = "SELECT session_id, job_id, notice_type FROM cc_job_notice_info";
 			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
 			res = stmt.executeQuery();
@@ -369,7 +369,7 @@ public class JobNoticeInfoDAOImpl implements JobNoticeInfoDAO {
 			conn = ConnectionManager.getConnectionManager().getConnection();
 			
 			//SQL文の定義
-			String sql = "SELECT * FROM cc_job_notice_info WHERE session_id = ? AND job_id = ? AND notice_type = ?";
+			String sql = "SELECT session_id, job_id, notice_type FROM cc_job_notice_info WHERE session_id = ? AND job_id = ? AND notice_type = ?";
 			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
 			
@@ -423,7 +423,7 @@ public class JobNoticeInfoDAOImpl implements JobNoticeInfoDAO {
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();	
 			//SQL文の定義
-			String sql = "SELECT * FROM cc_job_notice_info WHERE session_id = ? AND job_id = ?";
+			String sql = "SELECT session_id, job_id, notice_type FROM cc_job_notice_info WHERE session_id = ? AND job_id = ?";
 			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
 			
