@@ -456,7 +456,7 @@ public class JobStartMasterDAOImpl implements JobStartMasterDAO {
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();	
 			//SQL文の定義
-			String sql = "SELECT * FROM cc_job_start_mst";
+			String sql = "SELECT job_id FROM cc_job_start_mst";
 			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
 			res = stmt.executeQuery();
@@ -506,7 +506,7 @@ public class JobStartMasterDAOImpl implements JobStartMasterDAO {
 			conn = ConnectionManager.getConnectionManager().getConnection();
 			
 			//SQL文の定義
-			String sql = "SELECT * FROM cc_job_start_mst WHERE job_id = ?";
+			String sql = "SELECT job_id FROM cc_job_start_mst WHERE job_id = ?";
 			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
 			
