@@ -84,5 +84,35 @@ public class SelectSchedule {
 		
 		return -1;
 		
+		/**
+        //ジョブ名リスト取得
+        try {
+			m_jobs = manager.getJobs(monitorTypeId);
+		} catch (RemoteException e) {
+		}
+		
+        //ジョブ名リスト取得
+        for(int i = 0; i < m_jobs.length; i++){
+            //ジョブ(JobDetail)取得
+            JobDetail job = null;
+			try {
+				job = manager.getJobDetail(m_jobs[i], monitorTypeId);
+			} catch (RemoteException e) {
+			}
+
+            // ジョブ名を取得
+            if(monitorId.equals(job.getName())){
+            	// 有効/無効を取得
+                Integer valid = (Integer)job.getJobDataMap().get(QuartzConstant.VALID_KEY);
+                if(valid != null){
+                	return valid.intValue();
+                }
+                else{
+                	return -1;
+                }
+            }
+        }
+	    return -1;
+	    */
     }
 }
