@@ -102,11 +102,11 @@ public class EventLogDAOImpl implements EventLogDAO {
 
 			} else {
 				String msg = "EventLog data is not found.";
-				m_log.error("load() error : " + pk.toString() + msg);
+				m_log.error("load() error : " + pk.toString() + " SQLException " + msg);
 				throw new EJBException(msg);
 			}
 		} catch (SQLException e) {
-			m_log.error("load() error : " + pk.toString() , e);
+			m_log.error("load() error : " + pk.toString() + " SQLException");
 			throw new EJBException(e.getMessage());
 		} finally {
 			// コネクション、結果セット、プリペアドステートメントのクロース
@@ -121,7 +121,7 @@ public class EventLogDAOImpl implements EventLogDAO {
 					conn.close();
 				}
 			} catch (SQLException e1) {
-				m_log.error("load() error : " + pk.toString() , e1);
+				m_log.error("load() error : " + pk.toString() + " SQLException " + e1.getMessage());
 				throw new EJBException(e1.getMessage());
 			}
 		}
@@ -189,13 +189,14 @@ public class EventLogDAOImpl implements EventLogDAO {
 				String msg = "result row is not 1";
 				m_log.error("store() error : " + ejb.getPluginId() + ", "
 						+ ejb.getMonitorId() + ", " + ejb.getFacilityId() + ", "
-						+ ejb.getOutputDate() + " " + msg);
+						+ ejb.getOutputDate() + " SQLException" + msg);
 				throw new EJBException(msg);
 			}
 		} catch (SQLException e) {
 			m_log.error("store() error : " + ejb.getPluginId() + ", "
 					+ ejb.getMonitorId() + ", " + ejb.getFacilityId() + ", "
-					+ ejb.getOutputDate() , e);
+					+ ejb.getOutputDate() + " SQLException");
+			e.printStackTrace();
 			throw new EJBException(e.getMessage());
 		} finally {
 			// コネクション、結果セット、プリペアドステートメントのクロース
@@ -209,7 +210,8 @@ public class EventLogDAOImpl implements EventLogDAO {
 			} catch (SQLException e1) {
 				m_log.error("store() error : " + ejb.getPluginId() + ", "
 						+ ejb.getMonitorId() + ", " + ejb.getFacilityId() + ", "
-						+ ejb.getOutputDate() , e1);
+						+ ejb.getOutputDate() + " SQLException");
+				e1.printStackTrace();
 				throw new EJBException(e1.getMessage());
 			}
 		}
@@ -244,11 +246,11 @@ public class EventLogDAOImpl implements EventLogDAO {
 			
 			if (row != 1 ) {
 				String msg = "result row is not 1";
-				m_log.error("remove() error : " + pk.toString() + " " + msg);
+				m_log.error("remove() error : " + pk.toString() + " SQLException" + msg);
 				throw new EJBException(msg);	
 			}
 		} catch (SQLException e) {
-			m_log.error("remove() error : " + pk.toString() , e);
+			m_log.error("remove() error : " + pk.toString() + " SQLException");
 			throw new EJBException(e.getMessage());
 			
 		} finally {
@@ -260,7 +262,7 @@ public class EventLogDAOImpl implements EventLogDAO {
 					conn.close();
 				}
 			} catch (SQLException e1) {
-				m_log.error("remove() error : " + pk.toString() , e1);
+				m_log.error("remove() error : " + pk.toString() + " SQLException");
 				throw new EJBException(e1.getMessage());
 			}
 		}
@@ -335,17 +337,14 @@ public class EventLogDAOImpl implements EventLogDAO {
 			
 			if (row != 1) {
 				String msg = "result row is not 1";
-				m_log.error("create() error : " + ejb.getPluginId() + ", " + ejb.getMonitorId() + ", " + ejb.getFacilityId() + ", " + ejb.getOutputDate());
+				m_log.error("create() error : " + ejb.getPluginId() + ", " + ejb.getMonitorId() + ", " + ejb.getFacilityId() + ", " + ejb.getOutputDate() + " SQLException");
 				throw new EJBException(msg);
 			}
 		} catch (SQLException e) {
-			//想定されるエラー処理(再挿入するためDuplicateKeyを検知し、DuplicateKeyExceptionスローする)
 			if(e.getSQLState().equals("23505")){
-				m_log.info("create() error : " + ejb.getPluginId() + ", " + ejb.getMonitorId() + ", " + ejb.getFacilityId() + ", " + ejb.getOutputDate() + " SQLException" + " DuplicateKeyException");
+				m_log.info("create() error : " + ejb.getPluginId() + ", " + ejb.getMonitorId() + ", " + ejb.getFacilityId() + ", " + ejb.getOutputDate() + " SQLException" + "DuplicateKeyException ");
 				throw new DuplicateKeyException(e.getMessage());
 			}
-			//想定外のエラー処理
-			m_log.error("create() error : " + ejb.getPluginId() + ", " + ejb.getMonitorId() + ", " + ejb.getFacilityId() + ", " + ejb.getOutputDate(),e);
 			throw new CreateException(e.getMessage());
 		}finally{
 			try {
@@ -356,7 +355,7 @@ public class EventLogDAOImpl implements EventLogDAO {
 					conn.close();
 				}
 			} catch (SQLException e1) {
-				m_log.error("create() error : " + ejb.getPluginId() + ", " + ejb.getMonitorId() + ", " + ejb.getFacilityId() + ", " + ejb.getOutputDate() , e1);
+				m_log.error("create() error : " + ejb.getPluginId() + ", " + ejb.getMonitorId() + ", " + ejb.getFacilityId() + ", " + ejb.getOutputDate() + " SQLException");
 				throw new EJBException(e1.getMessage());
 			}
 		}
@@ -385,7 +384,7 @@ public class EventLogDAOImpl implements EventLogDAO {
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();	
 			//SQL文の定義
-			String sql = "SELECT * FROM cc_event_log";
+			String sql = "SELECT monitor_id,plugin_id,facility_id,output_date FROM cc_event_log";
 			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
 			res = stmt.executeQuery();
@@ -401,7 +400,7 @@ public class EventLogDAOImpl implements EventLogDAO {
 			}
 			
 		} catch (SQLException e) {
-			m_log.error("findAll() error : " , e);
+			m_log.error("findAll() error :  SQLException");
 			throw new EJBException(e.getMessage());
 		}  finally{
 			try {
@@ -413,7 +412,7 @@ public class EventLogDAOImpl implements EventLogDAO {
 					conn.close();
 				}
 			} catch (SQLException e1) {
-				m_log.error("findAll() error : " , e1);
+				m_log.error("findAll() error :  SQLException");
 				throw new EJBException(e1.getMessage());
 			}
 		}
@@ -442,7 +441,7 @@ public class EventLogDAOImpl implements EventLogDAO {
 			conn = ConnectionManager.getConnectionManager().getConnection();
 			
 			// SQL文の定義
-			String sql = "SELECT * FROM cc_event_log WHERE plugin_id = ? AND monitor_id = ? AND facility_id = ? AND output_date = ?";
+			String sql = "SELECT monitor_id,plugin_id,facility_id,output_date FROM cc_event_log WHERE plugin_id = ? AND monitor_id = ? AND facility_id = ? AND output_date = ?";
 			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
 
@@ -460,7 +459,7 @@ public class EventLogDAOImpl implements EventLogDAO {
 				throw new FinderException(msg);
 			}
 		} catch (SQLException e) {
-			m_log.error("find() error : " + pk.toString() , e);
+			m_log.error("find() error : " + pk.toString() + " SQLException");
 			throw new EJBException(e.getMessage());
 		}  finally{
 			try {
@@ -472,7 +471,7 @@ public class EventLogDAOImpl implements EventLogDAO {
 					conn.close();
 				}
 			} catch (SQLException e1) {
-				m_log.error("find() error : " + pk.toString() , e1);
+				m_log.error("find() error : " + pk.toString() + " SQLException");
 				throw new EJBException(e1.getMessage());
 			}
 			m_log.debug("findByPrimaryKey() end : " + pk.toString());
@@ -508,7 +507,7 @@ public class EventLogDAOImpl implements EventLogDAO {
 			conn = ConnectionManager.getConnectionManager().getConnection();	
 			//SQL文の定義
 			StringBuilder sql = new StringBuilder();
-			sql.append("SELECT * FROM cc_event_log ");
+			sql.append("SELECT monitor_id,plugin_id,facility_id,output_date FROM cc_event_log ");
 			sql.append("WHERE monitor_id = ? ");
 			sql.append("AND plugin_id = ? ");
 			sql.append("AND facility_id = ? ");
@@ -538,7 +537,7 @@ public class EventLogDAOImpl implements EventLogDAO {
 			}
 			
 		} catch (SQLException e) {
-			m_log.error("findByGenerationDateOrder() error : " , e);
+			m_log.error("findByGenerationDateOrder() error :  SQLException");
 			throw new EJBException(e.getMessage());
 		}  finally{
 			try {
@@ -550,7 +549,7 @@ public class EventLogDAOImpl implements EventLogDAO {
 					conn.close();
 				}
 			} catch (SQLException e1) {
-				m_log.error("findByGenerationDateOrder() error : " , e1);
+				m_log.error("findByGenerationDateOrder() error :  SQLException");
 				throw new EJBException(e1.getMessage());
 			}
 		}
@@ -601,7 +600,7 @@ public class EventLogDAOImpl implements EventLogDAO {
 			conn = ConnectionManager.getConnectionManager().getConnection();	
 			//SQL文の定義
 			StringBuffer sql = new StringBuffer();
-			sql.append("SELECT * FROM cc_event_log ");
+			sql.append("SELECT monitor_id,plugin_id,facility_id,output_date FROM cc_event_log ");
 			sql.append("WHERE " + sqlWhere.toString());
 			sql.append(" ORDER BY output_date");
 			
@@ -629,7 +628,7 @@ public class EventLogDAOImpl implements EventLogDAO {
 			}
 			
 		} catch (SQLException e) {
-			m_log.error("selectByMessageOrg() error : " , e);
+			m_log.error("selectByMessageOrg() error :  SQLException");
 			throw new EJBException(e.getMessage());
 		}  finally{
 			try {
@@ -641,7 +640,7 @@ public class EventLogDAOImpl implements EventLogDAO {
 					conn.close();
 				}
 			} catch (SQLException e1) {
-				m_log.error("selectByMessageOrg() error : " , e1);
+				m_log.error("selectByMessageOrg() error :  SQLException");
 				throw new EJBException(e1.getMessage());
 			}
 		}
@@ -760,7 +759,7 @@ public class EventLogDAOImpl implements EventLogDAO {
 			conn = ConnectionManager.getConnectionManager().getConnection();	
 			//SQL文の定義
 			StringBuffer sql = new StringBuffer();
-			sql.append("SELECT * FROM cc_event_log ");
+			sql.append("SELECT monitor_id,plugin_id,facility_id,output_date FROM cc_event_log ");
 			if(sqlWhere.length() > 0){
 				sql.append("WHERE " + sqlWhere.toString());
 			}
@@ -846,7 +845,7 @@ public class EventLogDAOImpl implements EventLogDAO {
 			}
 			
 		} catch (SQLException e) {
-			m_log.error("selectEvent() error : " , e);
+			m_log.error("selectEvent() error :  SQLException");
 			throw new EJBException(e.getMessage());
 		}  finally{
 			try {
@@ -858,7 +857,7 @@ public class EventLogDAOImpl implements EventLogDAO {
 					conn.close();
 				}
 			} catch (SQLException e1) {
-				m_log.error("selectEvent() error : " , e1);
+				m_log.error("selectEvent() error :  SQLException");
 				throw new EJBException(e1.getMessage());
 			}
 		}
@@ -1040,7 +1039,7 @@ public class EventLogDAOImpl implements EventLogDAO {
 			}
 			
 		} catch (SQLException e) {
-			m_log.error("countEvent() error : " , e);
+			m_log.error("countEvent() error :  SQLException");
 			throw e;
 		}  finally{
 			try {
@@ -1052,7 +1051,7 @@ public class EventLogDAOImpl implements EventLogDAO {
 					conn.close();
 				}
 			} catch (SQLException e1) {
-				m_log.error("countEvent() error : " , e1);
+				m_log.error("countEvent() error :  SQLException");
 				throw e1;
 			}
 		}
@@ -1228,7 +1227,8 @@ public class EventLogDAOImpl implements EventLogDAO {
 			// クエリを実行
 			row = stmt.executeUpdate();
 		} catch (SQLException e) {
-			m_log.error("confirmEvent() error : ", e);
+			m_log.error("confirmEvent() error :  SQLException");
+			m_log.error(e.getMessage());
 			throw e;
 		}  finally{
 			try {
@@ -1240,7 +1240,8 @@ public class EventLogDAOImpl implements EventLogDAO {
 					conn.close();
 				}
 			} catch (SQLException e1) {
-				m_log.error("confirmEvent() error : " , e1);
+				m_log.error("confirmEvent() error :  SQLException");
+				m_log.error(e1.getMessage());
 				throw e1;
 			}
 		}
@@ -1287,7 +1288,7 @@ public class EventLogDAOImpl implements EventLogDAO {
 			
 			//SQL文の定義
 			StringBuffer sql = new StringBuffer();
-			sql.append("SELECT * FROM cc_event_log ");
+			sql.append("SELECT monitor_id,plugin_id,facility_id,output_date FROM cc_event_log ");
 			sql.append("WHERE ");
 			
 			// ファシリティID設定
@@ -1412,7 +1413,7 @@ public class EventLogDAOImpl implements EventLogDAO {
 			}
 			
 		} catch (SQLException e) {
-			m_log.error("selectHighPriorityEvent() error : " , e);
+			m_log.error("selectHighPriorityEvent() error :  SQLException");
 			throw new EJBException(e.getMessage());
 		}  finally{
 			try {
@@ -1424,7 +1425,7 @@ public class EventLogDAOImpl implements EventLogDAO {
 					conn.close();
 				}
 			} catch (SQLException e1) {
-				m_log.error("selectHighPriorityEvent() error : " , e1);
+				m_log.error("selectHighPriorityEvent() error :  SQLException");
 				throw new EJBException(e1.getMessage());
 			}
 		}
