@@ -379,7 +379,7 @@ public class CollectorDAOImpl implements CollectorDAO {
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();
 			//SQL文の定義
-			String sql = "SELECT * FROM CC_COLLECTOR_PROFILE WHERE COLLECTORID = ?";
+			String sql = "SELECT collectorid FROM CC_COLLECTOR_PROFILE WHERE COLLECTORID = ?";
 			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
 			
@@ -432,7 +432,7 @@ public class CollectorDAOImpl implements CollectorDAO {
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();	
 			//SQL文の定義
-			String sql = "SELECT * FROM CC_COLLECTOR_PROFILE ORDER BY START_DATE";
+			String sql = "SELECT COLLECTORID FROM CC_COLLECTOR_PROFILE ORDER BY START_DATE";
 			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
 			res = stmt.executeQuery();
@@ -479,7 +479,7 @@ public class CollectorDAOImpl implements CollectorDAO {
 			conn = ConnectionManager.getConnectionManager().getConnection();
 			//SQL文の定義
 			String sql = 
-				"SELECT * FROM CC_COLLECTOR_PROFILE WHERE COLLECTOR_TYPE = ? ORDER BY START_DATE";
+				"SELECT COLLECTORID FROM CC_COLLECTOR_PROFILE WHERE COLLECTOR_TYPE = ? ORDER BY START_DATE";
 			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
 			stmt.setShort(1,(short)type);
@@ -530,7 +530,7 @@ public class CollectorDAOImpl implements CollectorDAO {
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();
 			//SQL文の定義
-			String sql = "SELECT * FROM CC_COLLECTOR_PROFILE " +
+			String sql = "SELECT COLLECTORID FROM CC_COLLECTOR_PROFILE " +
 						  "WHERE COLLECTOR_TYPE = 2 " +
 						  "AND PERIOD_MIN=-1 " +
 						  "AND STOP_DATE is null";
@@ -592,7 +592,7 @@ public class CollectorDAOImpl implements CollectorDAO {
 			conn = ConnectionManager.getConnectionManager().getConnection();
 			//SQL文の定義
 			String sql = 
-				"SELECT * FROM CC_COLLECTOR_PROFILE WHERE COLLECTOR_TYPE = ? AND TARGET_FACILITYID = ? ORDER BY START_DATE";
+				"SELECT COLLECTORID FROM CC_COLLECTOR_PROFILE WHERE COLLECTOR_TYPE = ? AND TARGET_FACILITYID = ? ORDER BY START_DATE";
 			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
 			stmt.setShort(1,(short)type);
