@@ -32,6 +32,7 @@ import com.clustercontrol.accesscontrol.util.LdapConnectionManager;
 import com.clustercontrol.accesscontrol.util.TimeKeeper;
 import com.clustercontrol.accesscontrol.util.TimeKeeperService;
 import com.clustercontrol.repository.bean.DeviceInfoAttributeConstant;
+import com.clustercontrol.repository.bean.FileSystemInfoAttributeConstant;
 import com.clustercontrol.repository.ejb.entity.DeviceInfoBean;
 import com.clustercontrol.repository.ejb.entity.DeviceInfoPK;
 import com.clustercontrol.util.apllog.AplLogger;
@@ -418,6 +419,31 @@ public class DeviceInfoDAOImpl implements DeviceInfoDAO {
 				//dn設定
 				ejb.setDn(dn.toString());
 				
+				//各種属性値をセットする
+				if (ejb.getDisplayName() != null) {
+					attrs.put(DeviceInfoAttributeConstant.DISPLAYNAME, ejb.getDisplayName());
+				}
+				
+				if (ejb.getDeviceName() != null) {
+					attrs.put(DeviceInfoAttributeConstant.DEVICENAME, ejb.getDeviceName());
+				}
+				
+				if (ejb.getSnmpOID() != null) {
+					attrs.put(DeviceInfoAttributeConstant.SNMPOID, ejb.getSnmpOID());
+				}
+				
+				if (ejb.getDeviceIndex() != null) {
+					attrs.put(DeviceInfoAttributeConstant.DEVICEINDEX, ejb.getDeviceIndex().toString());
+				}
+				
+				if (ejb.getDeviceType() != null) {
+					attrs.put(DeviceInfoAttributeConstant.DEVICETYPE, ejb.getDeviceType());
+				}
+				
+				if (ejb.getDescription() != null) {
+					attrs.put(DeviceInfoAttributeConstant.DESCRIPTION, ejb.getDescription());
+				}
+				
 				// LDAPへのアクセスが無応答になった場合に処理を中断するためのタイマースレッドを起動する。
 				timer = TimeKeeperService.start();
 				
