@@ -29,6 +29,7 @@ import javax.naming.NamingException;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
+import org.jboss.mq.selectors.ISelectorParser;
 
 import com.clustercontrol.accesscontrol.factory.AccessLock;
 import com.clustercontrol.bean.FacilityConstant;
@@ -38,6 +39,7 @@ import com.clustercontrol.bean.SnmpVersionConstant;
 import com.clustercontrol.repository.bean.FacilityAttributeConstant;
 import com.clustercontrol.repository.bean.FacilityTreeAttributeConstant;
 import com.clustercontrol.repository.bean.TopicConstant;
+import com.clustercontrol.repository.dao.DeviceInfoDAOImpl;
 import com.clustercontrol.repository.dao.FacilityDAOImpl;
 import com.clustercontrol.repository.dao.FacilityTreeDAOImpl;
 import com.clustercontrol.repository.ejb.entity.DeviceInfoLocal;
@@ -328,17 +330,19 @@ public class ModifyFacility {
     	AccessLock.lock(AccessLock.REPOSITORY);
 		
 		String facilityId = null;
-	    try {
+		try {
 			ArrayList values = null;
+			
 			//現在日時を取得
 			Date now = new Date();
 			
 			//ファシリティID取得
 			values = PropertyUtil.getPropertyValue(property, NodeProperty.FACILITY_ID);
-			facilityId = (String)values.get(0);
+			facilityId = checkString(values.get(0));
 			//ファシリティ名取得
 			values = PropertyUtil.getPropertyValue(property, NodeProperty.FACILITY_NAME);
-			String facilityName = (String)values.get(0);
+			String facilityName = checkString(values.get(0));
+			
 			
 			//Facilityを作成
 			FacilityLocal facility = FacilityUtil.getLocalHome().create(
@@ -514,11 +518,6 @@ public class ModifyFacility {
 //			FIXME　ソートの順番はとりあえずオンコードで100とする。
 		
 			facility.setSortValue(new Integer(DEFAULT_SORT_ORDER));
-			
-			//nullをセットすることでstore()を呼び出す。
-			facility = null;
-
-			//デバイスの配列を取得
 			ArrayList deviceList = PropertyUtil.getProperty(property, NodeProperty.DEVICE);
 			for(int i = 0; i < deviceList.size(); i++){
 			    //デバイスINDEXを取得
@@ -530,34 +529,30 @@ public class ModifyFacility {
 				values = PropertyUtil.getPropertyValue(deviceProperty, NodeProperty.DEVICE_TYPE);
 				String deviceType = checkString(values.get(0));
 				
-				if(deviceIndex != null && deviceType != null && !deviceType.equals("")){
-					//DeviceInfoを作成
-					DeviceInfoLocal device = DeviceInfoUtil.getLocalHome().create(
-							deviceIndex, 
-							deviceType,
-							facilityId);
+				//デバイス表示名を取得し、DeviceInfoに設定
+				values = PropertyUtil.getPropertyValue(deviceProperty, NodeProperty.DEVICE_DISPLAY_NAME);
+				String displayName = checkString(values.get(0));
+			    //デバイス名を取得し、DeviceInfoに設定
+				values = PropertyUtil.getPropertyValue(deviceProperty, NodeProperty.DEVICE_NAME);
+				String deviceName = checkString(values.get(0));
+				//デバイスOIDを取得し、DeviceInfoに設定
+				values = PropertyUtil.getPropertyValue(deviceProperty, NodeProperty.DEVICE_OID);
+				String snmpOID = checkString(values.get(0));
+				//説明を取得し、DeviceInfoに設定
+				values = PropertyUtil.getPropertyValue(deviceProperty, NodeProperty.DEVICE_DESCRIPTION);
+				String description = checkString(values.get(0));
 				
-					if(device != null){
-						//デバイス表示名を取得し、DeviceInfoに設定
-						values = PropertyUtil.getPropertyValue(deviceProperty, NodeProperty.DEVICE_DISPLAY_NAME);
-						device.setDisplayName(checkString(values.get(0)));
-						//デバイス名を取得し、DeviceInfoに設定
-						values = PropertyUtil.getPropertyValue(deviceProperty, NodeProperty.DEVICE_NAME);
-						device.setDeviceName(checkString(values.get(0)));
-					    //デバイスINDEXを取得し、DeviceInfoに設定
-						values = PropertyUtil.getPropertyValue(deviceProperty, NodeProperty.DEVICE_INDEX);
-						device.setDeviceIndex(checkInteger(values.get(0)));
-						//デバイスOIDを取得し、DeviceInfoに設定
-						values = PropertyUtil.getPropertyValue(deviceProperty, NodeProperty.DEVICE_OID);
-						device.setSnmpOID(checkString(values.get(0)));
-						//デバイスタイプを取得し、DeviceInfoに設定
-						values = PropertyUtil.getPropertyValue(deviceProperty, NodeProperty.DEVICE_TYPE);
-						device.setDeviceType(checkString(values.get(0)));
-						//説明を取得し、DeviceInfoに設定
-						values = PropertyUtil.getPropertyValue(deviceProperty, NodeProperty.DEVICE_DESCRIPTION);
-						device.setDescription(checkString(values.get(0)));
-					}
+				// デバイスを登録しない場合はcontinue
+				if (deviceIndex == null && deviceName == null &&
+						deviceType == null && snmpOID == null && description == null) {
+					continue;
 				}
+				
+				//dn, cnはDeviceInfoDAOImplで生成する
+				DeviceInfoLocal device = DeviceInfoUtil.getLocalHome()
+						.create(deviceIndex, deviceName, deviceType, snmpOID, description,
+								facilityId, displayName);
+				
 			}
 			
 			//ファイルシステムの配列を取得
@@ -568,29 +563,29 @@ public class ModifyFacility {
 				values = PropertyUtil.getPropertyValue(fileSystemProperty, NodeProperty.FILE_SYSTEM_INDEX);
 				Integer cn = checkInteger(values.get(0));
 				
-				if(cn != null){
-					//FileSystemInfoを作成
-					FileSystemInfoLocal fileSystem = FileSystemInfoUtil.getLocalHome().create(
-							cn, 
-							facilityId);
+				//表示名を取得し、FileSystemInfoにセット
+				values = PropertyUtil.getPropertyValue(fileSystemProperty, NodeProperty.FILE_SYSTEM_DISPLAY_NAME);
+				String displayName = checkString(values.get(0));
+			    //マウント位置を取得し、FileSystemInfoに設定
+				values = PropertyUtil.getPropertyValue(fileSystemProperty, NodeProperty.FILE_SYSTEM_MOUNT_POINT);
+				String fileSystemMountPoint = checkString(values.get(0));
+				//ファイルシステムOIDを取得し、FileSystemInfoに設定
+				values = PropertyUtil.getPropertyValue(fileSystemProperty, NodeProperty.FILE_SYSTEM_OID);
+				String snmpOID = checkString(values.get(0));
+				//ファイルシステムタイプを取得し、FileSystemInfoに設定
+				values = PropertyUtil.getPropertyValue(fileSystemProperty, NodeProperty.FILE_SYSTEM_TYPE);
+				String fileSystemType = checkString(values.get(0));
+				//説明を取得し、FileSystemInfoに設定
+				values = PropertyUtil.getPropertyValue(fileSystemProperty, NodeProperty.FILE_SYSTEM_DESCRIPTION);
+				String description = checkString(values.get(0));
 				
-					if(fileSystem != null){
-						//ファイルシステム表示名を取得し、FileSystemInfoに設定
-						values = PropertyUtil.getPropertyValue(fileSystemProperty, NodeProperty.FILE_SYSTEM_DISPLAY_NAME);
-						fileSystem.setDisplayName(checkString(values.get(0)));
-					    //マウント位置を取得し、FileSystemInfoに設定
-						values = PropertyUtil.getPropertyValue(fileSystemProperty, NodeProperty.FILE_SYSTEM_MOUNT_POINT);
-						fileSystem.setFileSystemMountPoint(checkString(values.get(0)));
-						//ファイルシステムOIDを取得し、FileSystemInfoに設定
-						values = PropertyUtil.getPropertyValue(fileSystemProperty, NodeProperty.FILE_SYSTEM_OID);
-						fileSystem.setSnmpOID(checkString(values.get(0)));
-						//ファイルシステムタイプを取得し、FileSystemInfoに設定
-						values = PropertyUtil.getPropertyValue(fileSystemProperty, NodeProperty.FILE_SYSTEM_TYPE);
-						fileSystem.setFileSystemType(checkString(values.get(0)));
-						//説明を取得し、FileSystemInfoに設定
-						values = PropertyUtil.getPropertyValue(fileSystemProperty, NodeProperty.FILE_SYSTEM_DESCRIPTION);
-						fileSystem.setDescription(checkString(values.get(0)));
-					}
+				if(cn != null){
+					//dnはFileSystemInfoDAOImplで生成する
+					FileSystemInfoLocal fileSystem = FileSystemInfoUtil
+							.getLocalHome().create(cn, fileSystemMountPoint,
+									fileSystemType, snmpOID, description,
+									facilityId, displayName);
+					
 				}
 			}
 			
@@ -637,6 +632,7 @@ public class ModifyFacility {
     	
     	String facilityId = null;
 	    try {
+	    	
 			ArrayList values = null;
 			Date now = new Date();
 			
@@ -833,13 +829,9 @@ public class ModifyFacility {
 			    m_log.debug("modifyNode() : " + e.getMessage());
 			}
 
-			// ファイルシステムの情報を取得した後で呼び出すため、コメントアウトした。
-			//nullをセットすることでstore()を呼び出す。
-			//facility = null;
-			
 			//デバイスの配列を取得
 			ArrayList deviceList = PropertyUtil.getProperty(property, NodeProperty.DEVICE);
-
+			
 			//デバイスの作成
 			for(int i = 0; i < deviceList.size(); i++){
 				//デバイスINDEXを取得
@@ -851,34 +843,30 @@ public class ModifyFacility {
 				values = PropertyUtil.getPropertyValue(deviceProperty, NodeProperty.DEVICE_TYPE);
 				String deviceType = checkString(values.get(0));
 				
-				if(deviceIndex != null && deviceType != null && !deviceType.equals("")){
-					//DeviceInfoを作成
-					DeviceInfoLocal device = DeviceInfoUtil.getLocalHome().create(
-							deviceIndex, 
-							deviceType,
-							facilityId);
-	
-					if(device != null){
-						//デバイス表示名を取得し、DeviceInfoに設定
-						values = PropertyUtil.getPropertyValue(deviceProperty, NodeProperty.DEVICE_DISPLAY_NAME);
-						device.setDisplayName(checkString(values.get(0)));
-					    //デバイス名を取得し、DeviceInfoに設定
-						values = PropertyUtil.getPropertyValue(deviceProperty, NodeProperty.DEVICE_NAME);
-						device.setDeviceName(checkString(values.get(0)));
-					    //デバイスINDEXを取得し、DeviceInfoに設定
-						values = PropertyUtil.getPropertyValue(deviceProperty, NodeProperty.DEVICE_INDEX);
-						device.setDeviceIndex(checkInteger(values.get(0)));
-						//デバイスOIDを取得し、DeviceInfoに設定
-						values = PropertyUtil.getPropertyValue(deviceProperty, NodeProperty.DEVICE_OID);
-						device.setSnmpOID(checkString(values.get(0)));
-						//デバイスタイプを取得し、DeviceInfoに設定
-						values = PropertyUtil.getPropertyValue(deviceProperty, NodeProperty.DEVICE_TYPE);
-						device.setDeviceType(checkString(values.get(0)));
-						//説明を取得し、DeviceInfoに設定
-						values = PropertyUtil.getPropertyValue(deviceProperty, NodeProperty.DEVICE_DESCRIPTION);
-						device.setDescription(checkString(values.get(0)));
-					}
+				//デバイス表示名を取得し、DeviceInfoに設定
+				values = PropertyUtil.getPropertyValue(deviceProperty, NodeProperty.DEVICE_DISPLAY_NAME);
+				String displayName = checkString(values.get(0));
+			    //デバイス名を取得し、DeviceInfoに設定
+				values = PropertyUtil.getPropertyValue(deviceProperty, NodeProperty.DEVICE_NAME);
+				String deviceName = checkString(values.get(0));
+				//デバイスOIDを取得し、DeviceInfoに設定
+				values = PropertyUtil.getPropertyValue(deviceProperty, NodeProperty.DEVICE_OID);
+				String snmpOID = checkString(values.get(0));
+				//説明を取得し、DeviceInfoに設定
+				values = PropertyUtil.getPropertyValue(deviceProperty, NodeProperty.DEVICE_DESCRIPTION);
+				String description = checkString(values.get(0));
+				
+				// デバイスを登録しない場合はcontinue
+				if (deviceIndex == null && deviceName == null &&
+						deviceType == null && snmpOID == null && description == null) {
+					continue;
 				}
+				
+				//dn, cnはDeviceInfoDAOImplで生成する
+				DeviceInfoLocal device = DeviceInfoUtil.getLocalHome()
+						.create(deviceIndex, deviceName, deviceType, snmpOID, description,
+								facilityId, displayName);
+				
 			}
 			
 			//Facilityと関連しているファイルシステムを削除
@@ -898,8 +886,6 @@ public class ModifyFacility {
 			} catch (RemoveException e) {
 			    m_log.debug("modifyNode() : " + e.getMessage());
 			}
-			//nullをセットすることでstore()を呼び出す。
-			facility = null;
 			
 			//ファイルシステムの配列を取得
 			ArrayList fileSystemList = PropertyUtil.getProperty(property, NodeProperty.FILE_SYSTEM);
@@ -911,29 +897,28 @@ public class ModifyFacility {
 				values = PropertyUtil.getPropertyValue(fileSystemProperty, NodeProperty.FILE_SYSTEM_INDEX);
 				Integer cn = checkInteger(values.get(0));
 				
-				if(cn != null){					
-					//FileSystemInfoを作成
-					FileSystemInfoLocal fileSystem = FileSystemInfoUtil.getLocalHome().create(
-							cn, 
-							facilityId);
+				//表示名を取得し、FileSystemInfoにセット
+				values = PropertyUtil.getPropertyValue(fileSystemProperty, NodeProperty.FILE_SYSTEM_DISPLAY_NAME);
+				String displayName = checkString(values.get(0));
+			    //マウント位置を取得し、FileSystemInfoに設定
+				values = PropertyUtil.getPropertyValue(fileSystemProperty, NodeProperty.FILE_SYSTEM_MOUNT_POINT);
+				String fileSystemMountPoint = checkString(values.get(0));
+				//ファイルシステムOIDを取得し、FileSystemInfoに設定
+				values = PropertyUtil.getPropertyValue(fileSystemProperty, NodeProperty.FILE_SYSTEM_OID);
+				String snmpOID = checkString(values.get(0));
+				//ファイルシステムタイプを取得し、FileSystemInfoに設定
+				values = PropertyUtil.getPropertyValue(fileSystemProperty, NodeProperty.FILE_SYSTEM_TYPE);
+				String fileSystemType = checkString(values.get(0));
+				//説明を取得し、FileSystemInfoに設定
+				values = PropertyUtil.getPropertyValue(fileSystemProperty, NodeProperty.FILE_SYSTEM_DESCRIPTION);
+				String description = checkString(values.get(0));
 				
-					if(fileSystem != null){
-						//ファイルシステム表示名を取得し、FileSystemInfoに設定
-						values = PropertyUtil.getPropertyValue(fileSystemProperty, NodeProperty.FILE_SYSTEM_DISPLAY_NAME);
-						fileSystem.setDisplayName(checkString(values.get(0)));
-					    //マウント位置を取得し、FileSystemInfoに設定
-						values = PropertyUtil.getPropertyValue(fileSystemProperty, NodeProperty.FILE_SYSTEM_MOUNT_POINT);
-						fileSystem.setFileSystemMountPoint(checkString(values.get(0)));
-						//ファイルシステムOIDを取得し、FileSystemInfoに設定
-						values = PropertyUtil.getPropertyValue(fileSystemProperty, NodeProperty.FILE_SYSTEM_OID);
-						fileSystem.setSnmpOID(checkString(values.get(0)));
-						//ファイルシステムタイプを取得し、FileSystemInfoに設定
-						values = PropertyUtil.getPropertyValue(fileSystemProperty, NodeProperty.FILE_SYSTEM_TYPE);
-						fileSystem.setFileSystemType(checkString(values.get(0)));
-						//説明を取得し、FileSystemInfoに設定
-						values = PropertyUtil.getPropertyValue(fileSystemProperty, NodeProperty.FILE_SYSTEM_DESCRIPTION);
-						fileSystem.setDescription(checkString(values.get(0)));
-					}
+				if(cn != null){
+					//dnはFileSystemInfoDAOImplで生成する
+					FileSystemInfoLocal fileSystem = FileSystemInfoUtil
+							.getLocalHome().create(cn, fileSystemMountPoint,
+									fileSystemType, snmpOID, description,
+									facilityId, displayName);
 				}
 			}
 			
