@@ -32,6 +32,7 @@ import org.eclipse.swt.widgets.Text;
 import com.clustercontrol.bean.DataRangeConstant;
 import com.clustercontrol.bean.HinemosModuleConstant;
 import com.clustercontrol.bean.ValidConstant;
+import com.clustercontrol.calendar.composite.CalendarIdListComposite;
 import com.clustercontrol.composite.CommonTableViewer;
 import com.clustercontrol.composite.StringVerifyListener;
 import com.clustercontrol.dialog.CommonDialog;
@@ -73,6 +74,9 @@ public class SnmpTrapCreateDialog extends CommonDialog {
 	/** 監視基本情報 */
 	private MonitorBasicScopeComposite monitorBasicComposite = null;
 	
+	/** カレンダ設定 */
+	CalendarIdListComposite calendarComposite = null;
+	
 	/** コミュニティ名 */
 	private Text textCommunityName = null;
 	
@@ -127,7 +131,7 @@ public class SnmpTrapCreateDialog extends CommonDialog {
      * @return 初期サイズ
      */
     protected Point getInitialSize() {
-        return new Point(750, 620);
+        return new Point(750, 650);
     }
 	
 	/**
@@ -164,6 +168,16 @@ public class SnmpTrapCreateDialog extends CommonDialog {
 		gridData.grabExcessHorizontalSpace = true;
 		monitorBasicComposite.setLayoutData(gridData);
 
+		/*
+		 * カレンダ
+		 */
+		calendarComposite = new CalendarIdListComposite(parent, SWT.NONE, true);
+		gridData = new GridData();
+		gridData.horizontalSpan = 15;
+		gridData.horizontalAlignment = GridData.FILL;
+		gridData.grabExcessHorizontalSpace = true;
+		calendarComposite.setLayoutData(gridData);
+		
 		/*
 		 * トラップ定義グループ
 		 */
@@ -325,6 +339,11 @@ public class SnmpTrapCreateDialog extends CommonDialog {
 		// 監視基本情報
 		monitorBasicComposite.setInputData(monitor);
 		
+		// カレンダID
+		if (monitor.getCalendarId() != null) {
+			calendarComposite.setText(monitor.getCalendarId());
+		}
+		
 		// コミュニティ名
 		if(monitor.getCommunityName() != null){
 			textCommunityName.setText(monitor.getCommunityName());
@@ -374,6 +393,12 @@ public class SnmpTrapCreateDialog extends CommonDialog {
 			return null;
 		}
 		
+		// カレンダID
+		if (calendarComposite.getText() != null
+				&& !"".equals((calendarComposite.getText()).trim())) {
+			info.setCalendarId(calendarComposite.getText());
+		}
+		
 		// コミュニティ名
 		if (this.textCommunityName.getText() != null
 				&& !"".equals((this.textCommunityName.getText()).trim())) {
