@@ -74,8 +74,6 @@ public class LogManager {
     /** 順序を管理するフィルタ情報のリスト。 */
     private List<LogFilterInfo> orderList = null;
 
-    /** フィルタIDの採番カウンタ */    
-    private int _nextId = 0;    
 
     /**
 	 * コンストラクタ。<BR>
@@ -90,7 +88,6 @@ public class LogManager {
 	 * @see #loadLog()
 	 */
     public void initialize() {
-    	_nextId = 0; 
         this.loadLog();
     }
 
@@ -144,7 +141,7 @@ public class LogManager {
         // 順序は一番後ろとする。
         log.setOrderNo(order);
         // 暫定のログIDを振り分ける。
-        log.setLogId(getNextId());
+        log.setLogId("newLog" + order);
 
         this.cashe.put(log.getLogId(), log);
         this.orderList.add(log);
@@ -361,7 +358,7 @@ public class LogManager {
         	Object o = ite.next();
             LogFilterInfo log = (LogFilterInfo)o;
 
-            log.setLogId(getNextId());
+            log.setLogId("newLog" + index);
             this.cashe.put(log.getLogId(), log);
             this.orderList.add(log);
             index++;
@@ -395,12 +392,4 @@ public class LogManager {
 
         return true;
     }
-    /**    
-	* 新しいフィルタに利用するIDを採番する    
-	* @return    
-	*/  
-	private synchronized String getNextId() {    
-	return "LOGID" + String.format("%06d", _nextId++);  
-	}  
-
 }
\ No newline at end of file
